#!/bin/bash
#
# Made by Gert Hulselmans for Ultimate Boot CD
# http:/www.ultimatebootcd.com/
#
# Last time edited: 12 Apr 2010
#
# This script updates the definition files of F-Prot to the last version.

update()
{
    # Save IFS
    SAVED_IFS=$IFS
    # Make IFS a empty string. Otherwise it will convert newlines to spaces 
    # in $URL_UPDATE_SITES variable
    IFS=

    # Get the link to the definition file
    # Note: it is necessary to enclose '/' in square brackets for bash/Win32
    URL_UPDATE_SITES=`grep -o fprot[[:digit:]].ctmail.com "${FPROT_TEMPDIR}/fprot-update-link.xml"`
    URL_UPDATE_PATH=`grep -E -m 1 -o "[/][[:xdigit:]]{9,}[/]antivir.def" "${FPROT_TEMPDIR}/fprot-update-link.xml"`

    echo "Start downloading the F-Prot definition file"
    echo '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~'
    echo

    # Download antivir.def file
    while [ -n "${URL_UPDATE_SITES}" ]; do
        URL_UPDATE_SITE=`echo "${URL_UPDATE_SITES}" | sed -n '1 p'`
        URL_UPDATE_SITES=`echo "${URL_UPDATE_SITES}" | sed '1 d'`
        rm -f "${FPROT_TEMPDIR}/definitions/opt/f-prot/antivir.def"
        wget -P "${FPROT_TEMPDIR}/definitions/opt/f-prot/" "${URL_UPDATE_SITE}${URL_UPDATE_PATH}"
        if [ "$?" -eq "0" -a -f "${FPROT_TEMPDIR}/definitions/opt/f-prot/antivir.def" ]; then
            DOWNLOADED="true"
            break
        fi
    done

    if [ "$DOWNLOADED" != "true" ]; then
        echo
        echo "ERROR: Couldn't download 'antivir.def' file from any of the F-Prot servers."
        exit 1
    fi

    # Restore IFS
    IFS=$SAVED_IFS

    echo
    echo 'Download finished.'
    echo
    echo

    # Remove the old 'fprot-definitions.txz' file
    chmod a+w './../../../../pmagic/pmodules/fprot-definitions.txz'
    rm -f './../../../../pmagic/pmodules/fprot-definitions.txz'

    echo "Make 'fprot-definitions.txz' file"
    echo '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~'

    # Compress, the definition file of F-Prot
    tar -cv -C "${FPROT_TEMPDIR}/definitions/" . | "$prgXZ" -z - > './../../../../pmagic/pmodules/fprot-definitions.txz'
    chmod a-w './../../../../pmagic/pmodules/fprot-definitions.txz'

    mv -f "${FPROT_TEMPDIR}/fprot-update-link.xml" "${FPROT_TEMPDIR}/fprot-update-link.xml.old"
}

# Start of the script
echo
echo "Update definition file of F-Prot to the last version"
echo '____________________________________________________'
echo
echo

SCRIPTFILE="$(cd "${0%/*}" 2>/dev/null; echo "$PWD"/"${0##*/}")"
SCRIPTDIR=`dirname "$SCRIPTFILE"`
cd "$SCRIPTDIR"

ls '../../../../ubcd/tools/linux/antivirus/fprot.sh' > /dev/null 2>&1

if [ "$?" -eq "0" ]; then

    FPROT_TEMPDIR="/tmp/ubcd-temp/f-prot"
    mkdir -p "${FPROT_TEMPDIR}"

    if [ "$?" -eq "0" ]; then
        FPROT_TEMPDIR=`cd "${FPROT_TEMPDIR}"; echo "${PWD}"`
    
        cd "${SCRIPTDIR}"
    
        # Save IFS
        SAVED_IFS=$IFS
    
        # Poor man's 'which' command
        prgXZ=''
        IFS=:
        for i in $PATH ; do
            if [ -x "$i/xz" ] ; then
            prgXZ="$i/xz"
            break
            fi
        done
    
        # Restore IFS
        IFS=$SAVED_IFS
    
        if [ -n "$prgXZ" ]; then
            # Remove 'fprot-update-link.xml' in case that it still exist.
            rm -f "${FPROT_TEMPDIR}/fprot-update-link.xml"
    
            # Get the file that contains the link to the last definition file
            wget -O "${FPROT_TEMPDIR}/fprot-update-link.xml" 'http://directupdates.f-prot.net/cgi-bin/get_update_info?protocol=2&key=AFPXJ5KN83983257LJHG64S7NSTA6CABA2'
		echo "got it"
    
            if [ -f "${FPROT_TEMPDIR}/fprot-update-link.xml.old" ]; then
                # Compare the link to the definition file for the new and old 'fprot-update-link.xml'
                URL_UPDATE_PATH_NEW=`grep -o [/]files[/]defs[/].*[/]antivir.def "${FPROT_TEMPDIR}/fprot-update-link.xml"`
                URL_UPDATE_PATH_OLD=`grep -o [/]files[/]defs[/].*[/]antivir.def "${FPROT_TEMPDIR}/fprot-update-link.xml.old"`
        
                if [ "$URL_UPDATE_PATH_NEW" = "$URL_UPDATE_PATH_OLD" ]; then
                    echo
                    echo "Antivirus definition file for F-Prot is already up to date."
                else
                    update
                fi
            else
                update
            fi
        else
            echo "xz was not found, install it and try again."
            echo 'Site: http://tukaani.org/xz/'
        fi

    else
    	echo "ERROR: Couldn't create directory '${FPROT_TEMPDIR}' for storing temporary files."
    fi
else
    echo "ERROR: fprot.sh isn't run from inside the extracted UBCD directory:"
    echo '       (./ubcd/tools/linux/antivirus/fprot.sh)'
fi

echo

